#!/bin/sh
#
# @package      hubzero-submit-distributor
# @file         Scripts/boinc/submitbatchjob.sh
# @copyright    Copyright 2017-2018 The Regents of the University of California.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2017-2018 The Regents of the University of California
# All rights reserved.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of The Regents of the University of California.
#
if [ $# -lt 3 ] ; then
   echo usage: $0 jobWorkingDirectory jobScratchDirectory jobDescriptionFile
   exit 64
fi

jobWorkingDirectory=$1
jobScratchDirectory=$2
jobDescriptionFile=$3

binDirectory=$(readlink -f $(dirname $0))
export PATH=${binDirectory}:${PATH}

cd ${jobWorkingDirectory}
exitStatus=$?

if [ ${exitStatus} -eq 0 ] ; then
   case ${jobDescriptionFile} in
      *.boinc)
         localJobIdinstanceId=$(basename ${jobDescriptionFile} .boinc)
         localJobId=${localJobIdinstanceId%%_*}
         instanceId=${localJobIdinstanceId#*_}
         runName=$(basename ${jobWorkingDirectory})
         BATCHID=$(cat .__remote_jobid.${localJobId}_${instanceId})
         if [ ${instanceId} -eq 0 ] ; then
            date +"%s" > .__timestamp_start.${localJobId}_0
            cat > .__time_results.${localJobId}_0 << EOF
real 0.00
user 0.00
sys 0.00
EOF
            ${binDirectory}/submitBatchJobs.py ${runName} ${localJobId} ${BATCHID}
         else
            ${binDirectory}/submitBatchJob.py ${localJobId} ${instanceId} ${BATCHID}
         fi
         exitStatus=$?
         if [ ${exitStatus} -eq 0 ] ; then
            JOBID=${BATCHID}
         else
            JOBID="-1"
         fi
         if [ $# -gt 3 ] ; then
            logRecord=`date`
            shift 3
            while [ $# -gt 0 ] ; do
               logRecord=${logRecord}'\t'$1
               shift 1
            done
            logRecord=${logRecord}'\t'${JOBID}
            echo -e ${logRecord} >> /home/gridman/nanoHUBjobs/boinclog
         fi
         ;;
      *)
         echo "Invalid job class ${jobDescriptionFile}"
         exitStatus=23
         ;;
   esac
fi

if [ ${exitStatus} -eq 0 ] ; then
   echo "${JOBID}"
else
   echo "-1"
fi

exit ${exitStatus}
